@@ -55,15 +55,25 @@ def get_branches(ownername, repo_slug, username, password=''):
     return _json_or_error(r)
 
 
-def create_repository(name, username, password, scm='hg', is_private=True):
+def create_repository(name, username, password, scm='hg', is_private=True, owner=''):
     url = BASE_URL + 'repositories/'
     payload = {'name': name,
                'scm': scm,
                'is_private': str(bool(is_private))}
+    if owner != '':
+        payload['owner'] = owner
     r = requests.post(url, data=payload, auth=(username, password))
     return _json_or_error(r)
 
 
+def set_privilege(ownername, repo_slug, privilege, privilege_account, username, password):
+    url = BASE_URL + 'privileges/%s/%s/%s' % (ownername, repo_slug, privilege_account)
+    if privilege == 'none':
+        r = requests.delete(url, auth=(username, password))
+    else:
+        r = requests.put(url, data=privilege, auth=(username, password))
+    return _json_or_error(r)
+
 def update_repository(username, repo_slug, password, **opts):
     url = BASE_URL + 'repositories/%s/%s/' % (username, repo_slug)
     if opts.get('is_private'):
@@ -84,7 +94,7 @@ def download_file(repo_user, repo_slug, filename, username='', password=''):
     url = 'https://bitbucket.org/%s/%s/downloads/%s' % \
         (repo_user, repo_slug, filename)
 
-    print url
+    print(url)
     if password:
         r = requests.get(url, auth=HTTPDigestAuth(username, password))
     else:
